package com.ynet.life.message;

import com.ynet.gene.core.Context;
import com.ynet.gene.data.InvalidArgumentException;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.gene.data.ObjectNotFoundException;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.format.LifeFormat;
import java.util.Map;

/* loaded from: com_ynet_life_message.jar:com/ynet/life/message/MessageFormatter.class */
public class MessageFormatter {
    private static Map MESSAGE_CONFIG_MAP = null;

    private MessageFormatter() {
    }

    public static void initMessageConfig(String fileName) {
        MESSAGE_CONFIG_MAP = MessageConfigXMLReader.initializeFrom(fileName);
    }

    public static String getMessage(String businessCode, String formatId, String language, Object srcData) throws TranFailException {
        if (MESSAGE_CONFIG_MAP == null) {
            Trace.logError("LifeMsg", "未装载消息配置文件");
            throw new TranFailException("EBLN5004", "未装载消息配置文件");
        }
        MessageConfig messageConfig = (MessageConfig) MESSAGE_CONFIG_MAP.get(businessCode);
        if (messageConfig == null) {
            Trace.logError("LifeMsg", "消息配置文件中未定义该业务代码：".concat(String.valueOf(businessCode)));
            throw new TranFailException("EBLN5004", "消息配置文件中未定义该业务代码：".concat(String.valueOf(businessCode)));
        }
        String format = messageConfig.getFormat(formatId, language);
        if (format == null) {
            Trace.logError("LifeMsg", "消息配置文件中未定义对应的格式：" + formatId + "；业务代码：" + businessCode);
            throw new TranFailException("EBLN5004", "消息配置文件中未定义对应的格式：" + formatId + "；业务代码：" + businessCode);
        }
        StringBuffer message = new StringBuffer();
        int i = 0;
        while (true) {
            int lastPos = i;
            int pos = format.indexOf("${", lastPos);
            if (pos < 0) {
                message.append(format.substring(lastPos));
                return message.toString();
            }
            message.append(format.substring(lastPos, pos));
            int lastPos2 = pos + 2;
            int pos2 = format.indexOf("}", lastPos2);
            if (pos2 < 0) {
                Trace.logError("LifeMsg", "未找到对应的变量结束符}");
                throw new TranFailException("EBLN5004", "未找到对应的变量结束符}");
            }
            String dataName = format.substring(lastPos2, pos2);
            try {
                String dataValue = getOriginalDataValue(dataName, srcData);
                MessageField messageField = messageConfig.getField(dataName);
                if (messageField == null) {
                    dataValue = getWrappedDataValue(dataValue, messageField, language);
                }
                message.append(dataValue);
                i = pos2 + 1;
            } catch (InvalidArgumentException e) {
                Trace.logError("LifeMsg", "消息文件中配置的[" + dataName + "]为非法变量名", e);
                throw new TranFailException("EBLN5004", "消息文件中配置的[" + dataName + "]为非法变量名", e);
            } catch (ObjectNotFoundException e2) {
                Trace.logError("LifeMsg", "未找到变量名[" + dataName + "]对应的数据", e2);
                throw new TranFailException("EBLN5004", "未找到变量名[" + dataName + "]对应的数据", e2);
            }
        }
    }

    protected static String getWrappedDataValue(String srcValue, MessageField messageField, String language) {
        if (messageField == null) {
            return srcValue;
        }
        String destValue = null;
        switch (messageField.getType()) {
            case MessageField.MESSAGE_TYPE_ACCOUNT /* 0 */:
                if (messageField.isMask() && srcValue.length() > 4) {
                    destValue = "****" + srcValue.substring(srcValue.length() - 4);
                    break;
                }
                break;
            case MessageField.MESSAGE_TYPE_AMOUNT /* 1 */:
                destValue = LifeFormat.formatCurrency(srcValue);
                break;
            case MessageField.MESSAGE_TYPE_CURRENCY /* 2 */:
                destValue = LifeStandard.getAppDisplay("CURRENCY_TYPE", srcValue, language);
                break;
            case MessageField.MESSAGE_TYPE_DATETIME /* 3 */:
                destValue = LifeFormat.formatDate(srcValue, messageField.getFormat());
                break;
            case MessageField.MESSAGE_TYPE_PARAMETER /* 4 */:
                destValue = LifeStandard.getAppDisplay(messageField.getParamCode(), srcValue, language);
                break;
        }
        return destValue;
    }

    protected static String getOriginalDataValue(String dataName, Object srcData) throws ObjectNotFoundException, InvalidArgumentException {
        if (srcData instanceof Context) {
            return (String) ((Context) srcData).getDataValue(dataName);
        }
        if (srcData instanceof KeyedCollection) {
            return (String) ((KeyedCollection) srcData).getDataValue(dataName);
        }
        if (srcData instanceof Map) {
            return (String) ((Map) srcData).get(dataName);
        }
        throw new InvalidArgumentException("srcData must be a Context, KeyedCollection or Map object.");
    }
}
